<?php
#
# Project:  Initialize variables and arrays
# Language: php
# Author:   Denny Schlesinger
# Date:     December 12, 2011
#
# It is good practice to initialize all php variables and arrays.
# Until now there was no simple way of doing so. There is a 2003
# solution by Amit Arora of digitalamit.com but which relies on 
# GLOBAL variables which is not only a bad idea but supposedly 
# GLOBALS will be deprecated in php version 6. My thanks to Amit
# for the inspiration!
#
# The core problem is that variables cannot be called by reference.
# But arrays can and THAT is at the heart of the solution!
# 
# You still can't initialize variables globally but if one uses 
# array elements in place of variables, then the solution is easy.
# I use arrays extensively. For example, on forms I put all the various 
# error messages in an error array. Instead of using
#     $thisError
#     $thatError
# I use
#     $error['this']
#     $error['that']
#
# BTW, the function can also initialize to default values using a 
# key=>value pair in an array. As the code is written, the default 
# value is used only if the element is not initialized. To force the
# use of the default, comment out the if statement:
#
#   // if(!isset($array[$k[0]])) {       # if not initialized
#        $array[$k[0]] = $key[$k[0]];  # set value
#   // }
#
#
# On to the code!
#
#


# array to be initialized
$input = array('a'=>'aaa', 'b'=>'bbb', 'e'=>'eee');

# initialize elements c, d and e
# note: you can omit 'a' and 'b'
initVars($input, 'a', 'b', 'c', array('d'=>'ddd'), array('e'=>'XXX'), 'f');

#show result
echo "input= \n<pre>\n";
print_r ($input);
echo "</pre>\n";


# the array to be initialized is passed by reference
function initVars(&$array) {

    $keys = func_get_args();                  # get function's arguments
    array_shift($keys);                       # drop the initial array
    foreach($keys as $key) {
        if(is_array($key)) {                  # if default value
            $k = array_keys($key);            # get key
            if(!isset($array[$k[0]])) {       # if not initialized
                $array[$k[0]] = $key[$k[0]];  # set default value
            }
        } elseif(!isset($array[$key])) {      # else, if not initialized
            $array[$key] = '';                # initialize empty
        }
    }

}

?>